@@ -32,6 +32,8 @@ def compare(ctx,commit):
 
 
     full_list_of_commits = commits_full_list(repo)
+    click.echo('\n'.join(color_diff("-Red lines are from prior version. \n+Green lines are from current version".splitlines())))
+    click.echo("Learn how to read diff output here: https://gitutor.io/guide/gt-compare.html#understanding-the-output \n")
     answer = prompt_for_commit_selection(full_list_of_commits, 'Select commit to compare')
     if answer:
         answer_hash = answer['commit'][:7]
